@@ -6,7 +6,7 @@ import config
 app = Flask(__name__)
 app.config.from_object(config)
 
-@app.route("/", methods=['PUT'])
+@app.route("/", methods=['POST', 'PUT'])
 def index():
     data = request.data
     SAVE_FILE = "%s/%s" % (app.config['SAVE_FILE_PATH'], app.config['SAVE_FILE_NAME'])
@@ -15,10 +15,13 @@ def index():
         with open(SAVE_FILE, "w") as x:
             x.write(data)
 
+        COMMAND = "coffee --compile --output %s %s" % (app.config['JS_FILE_PATH'], SAVE_FILE)
         # Compile
-        subprocess.Popen("coffee --compile %s --output %s" % (SAVE_FILE, JS_FILE), shell=True).wait()
+        # File --output.coffee not found?
+        subprocess.Popen(COMMAND, shell=True).wait()
 
-    return open(JS_FILE).read()
+        return open(JS_FILE).read()
+    return "Nope"
  
 def main():
     app.debug = config.DEBUG 
